/* magick/magick_config.h.in.  Generated from configure.ac by autoheader.  */

/* Define if building universal (internal helper macro) */
#undef AC_APPLE_UNIVERSAL_BUILD

/* Define if coders and filters are to be built as modules. */
#undef BuildMagickModules

/* Disable OpenMP for algorithms which sometimes run slower */
#undef DisableSlowOpenMP

/* Enable broken/dangerous file formats support */
#undef EnableBrokenCoders

/* C compiler used for compilation */
#undef GM_BUILD_CC

/* CFLAGS used for C compilation */
#undef GM_BUILD_CFLAGS

/* arguments passed to configure */
#undef GM_BUILD_CONFIGURE_ARGS

/* CPPFLAGS used for preprocessing */
#undef GM_BUILD_CPPFLAGS

/* C++ compiler used for compilation */
#undef GM_BUILD_CXX

/* CXXFLAGS used for C++ compilation */
#undef GM_BUILD_CXXFLAGS

/* Host identification triplet */
#undef GM_BUILD_HOST

/* LDFLAGS used for linking */
#undef GM_BUILD_LDFLAGS

/* LIBS used for linking */
#undef GM_BUILD_LIBS

/* Define if C++ compiler supports __func__ */
#undef HAS_CPP__func__

/* Define if C compiler supports __func__ */
#undef HAS_C__func__

/* Define to 1 if you have the `atoll' function. */
#undef HAVE_ATOLL

/* define if bool is a built-in type */
#undef HAVE_BOOL

/* Define to 1 if you have the `clock_getres' function. */
#undef HAVE_CLOCK_GETRES

/* Define to 1 if you have the `clock_gettime' function. */
#undef HAVE_CLOCK_GETTIME

/* define if the compiler supports const_cast<> */
#undef HAVE_CONST_CAST

/* Define to 1 if you have the `cosf' function. */
#undef HAVE_COSF

/* Define to 1 if you have the `CryptGenRandom' function. */
#undef HAVE_CRYPTGENRANDOM

/* Define to 1 if you have the `ctime_r' function. */
#undef HAVE_CTIME_R

/* Define to 1 if you have the declaration of `pread', and to 0 if you don't.
   */
#undef HAVE_DECL_PREAD

/* Define to 1 if you have the declaration of `pwrite', and to 0 if you don't.
   */
#undef HAVE_DECL_PWRITE

/* Define to 1 if you have the declaration of `strlcpy', and to 0 if you
   don't. */
#undef HAVE_DECL_STRLCPY

/* Define to 1 if you have the declaration of `vsnprintf', and to 0 if you
   don't. */
#undef HAVE_DECL_VSNPRINTF

/* define if the compiler supports default template parameters */
#undef HAVE_DEFAULT_TEMPLATE_PARAMETERS

/* Have a /dev/urandom device for producing random bytes */
#undef HAVE_DEV_URANDOM

/* Define to 1 if you have the <dirent.h> header file, and it defines `DIR'.
   */
#undef HAVE_DIRENT_H

/* Define to 1 if you have the <dlfcn.h> header file. */
#undef HAVE_DLFCN_H

/* define if the compiler supports exceptions */
#undef HAVE_EXCEPTIONS

/* define if the compiler supports the explicit keyword */
#undef HAVE_EXPLICIT

/* Define to 1 if you have the `fabsf' function. */
#undef HAVE_FABSF

/* Define to 1 if you have the `fcntl' function. */
#undef HAVE_FCNTL

/* Define to 1 if fseeko (and presumably ftello) exists and is declared. */
#undef HAVE_FSEEKO

/* Define to 1 if you have the `fstatvfs' function. */
#undef HAVE_FSTATVFS

/* Define to 1 if you have the <ft2build.h> header file. */
/* #undef HAVE_FT2BUILD_H */

/* Define to 1 if you have the `ftime' function. */
#undef HAVE_FTIME

/* Define to 1 if you have the `getc_unlocked' function. */
#undef HAVE_GETC_UNLOCKED

/* Define to 1 if you have the `getexecname' function. */
#undef HAVE_GETEXECNAME

/* Define to 1 if you have the `getpagesize' function. */
#undef HAVE_GETPAGESIZE

/* Define to 1 if you have the `getpid' function. */
#undef HAVE_GETPID

/* Define to 1 if you have the `getpwnam_r' function. */
#undef HAVE_GETPWNAM_R

/* Define to 1 if you have the `getrlimit' function. */
#undef HAVE_GETRLIMIT

/* Define to 1 if you have the <inttypes.h> header file. */
#undef HAVE_INTTYPES_H

/* Define if you have the <lcms2.h> header file. */
#undef HAVE_LCMS2_H

/* Define if you have the <lcms2/lcms2.h> header file. */
#undef HAVE_LCMS2_LCMS2_H

/* Define to 1 if you have the `lltostr' function. */
#undef HAVE_LLTOSTR

/* Define to 1 if you have the `localtime_r' function. */
#undef HAVE_LOCALTIME_R

/* Define to 1 if you have the `logf' function. */
#undef HAVE_LOGF

/* Define to 1 if the type `long double' works and has more range or precision
   than `double'. */
#undef HAVE_LONG_DOUBLE_WIDER

/* Define to 1 if you have the <machine/param.h> header file. */
#undef HAVE_MACHINE_PARAM_H

/* Define to 1 if you have the <mach-o/dyld.h> header file. */
#undef HAVE_MACH_O_DYLD_H

/* Define to 1 if you have the `madvise' function. */
#undef HAVE_MADVISE

/* Define to 1 if you have the <malloc.h> header file. */
#undef HAVE_MALLOC_H

/* Define to 1 if you have the `mallopt' function. */
#undef HAVE_MALLOPT

/* Define to 1 if you have the <memory.h> header file. */
#undef HAVE_MEMORY_H

/* Define to 1 if you have a `mmap' system call which handles coherent file
   I/O. */
#undef HAVE_MMAP_FILEIO

/* define if the compiler supports the mutable keyword */
#undef HAVE_MUTABLE

/* define if the compiler implements namespaces */
#undef HAVE_NAMESPACES

/* Define to 1 if you have the <ndir.h> header file, and it defines `DIR'. */
#undef HAVE_NDIR_H

/* define if the compiler accepts the new for scoping rules */
#undef HAVE_NEW_FOR_SCOPING

/* Define to 1 if you have the `pclose' function. */
#undef HAVE_PCLOSE

/* Define to 1 if you have the `poll' function. */
#undef HAVE_POLL

/* Define to 1 if you have the `popen' function. */
#undef HAVE_POPEN

/* Define to 1 if you have the `posix_fadvise' function. */
#undef HAVE_POSIX_FADVISE

/* Define to 1 if you have the `posix_fallocate' function. */
#undef HAVE_POSIX_FALLOCATE

/* Define to 1 if you have the `posix_madvise' function. */
#undef HAVE_POSIX_MADVISE

/* Define to 1 if you have the `posix_memalign' function. */
#undef HAVE_POSIX_MEMALIGN

/* Define to 1 if you have the `posix_spawnp' function. */
#undef HAVE_POSIX_SPAWNP

/* Define to 1 if you have the `pread' function. */
#undef HAVE_PREAD

/* Define to 1 if you have the <process.h> header file. */
#undef HAVE_PROCESS_H

/* Define if you have POSIX threads libraries and header files. */
#undef HAVE_PTHREAD

/* Define to 1 if you have the `putc_unlocked' function. */
#undef HAVE_PUTC_UNLOCKED

/* Define to 1 if you have the `pwrite' function. */
#undef HAVE_PWRITE

/* Define to 1 if you have the `qsort_r' function. */
#undef HAVE_QSORT_R

/* Define to 1 if you have the `raise' function. */
#undef HAVE_RAISE

/* Define to 1 if you have the `rand_r' function. */
#undef HAVE_RAND_R

/* Define to 1 if you have the `readdir_r' function. */
#undef HAVE_READDIR_R

/* Define to 1 if you have the `readlink' function. */
#undef HAVE_READLINK

/* Define to 1 if you have the `realpath' function. */
#undef HAVE_REALPATH

/* Define to 1 if you have the `seekdir' function. */
#undef HAVE_SEEKDIR

/* Define to 1 if you have the `select' function. */
#undef HAVE_SELECT

/* Define to 1 if you have the `setrlimit' function. */
#undef HAVE_SETRLIMIT

/* Define to 1 if you have the `sigaction' function. */
#undef HAVE_SIGACTION

/* Define to 1 if you have the `sigemptyset' function. */
#undef HAVE_SIGEMPTYSET

/* Define to 1 if you have the `sinf' function. */
#undef HAVE_SINF

/* Define to 1 if you have the `spawnvp' function. */
#undef HAVE_SPAWNVP

/* Define to 1 if you have the `sqrtf' function. */
#undef HAVE_SQRTF

/* define if the compiler supports static_cast<> */
#undef HAVE_STATIC_CAST

/* define if the compiler supports ISO C++ standard library */
#undef HAVE_STD

/* Define to 1 if you have the <stdint.h> header file. */
#undef HAVE_STDINT_H

/* Define to 1 if you have the <stdlib.h> header file. */
#undef HAVE_STDLIB_H

/* define if the compiler supports Standard Template Library */
#undef HAVE_STL

/* Define to 1 if you have the `strerror' function. */
#undef HAVE_STRERROR

/* Define to 1 if you have the `strerror_r' function. */
#undef HAVE_STRERROR_R

/* Define to 1 if you have the <strings.h> header file. */
#undef HAVE_STRINGS_H

/* Define to 1 if you have the <string.h> header file. */
#undef HAVE_STRING_H

/* Define to 1 if you have the `strlcat' function. */
#undef HAVE_STRLCAT

/* Define to 1 if you have the `strlcpy' function. */
#undef HAVE_STRLCPY

/* Define to 1 if you have the `strtoll' function. */
#undef HAVE_STRTOLL

/* Define to 1 if you have the <sun_prefetch.h> header file. */
#undef HAVE_SUN_PREFETCH_H

/* Define to 1 if you have the `sysconf' function. */
#undef HAVE_SYSCONF

/* Define to 1 if you have the <sys/dir.h> header file, and it defines `DIR'.
   */
#undef HAVE_SYS_DIR_H

/* Define to 1 if you have the <sys/mman.h> header file. */
#undef HAVE_SYS_MMAN_H

/* Define to 1 if you have the <sys/ndir.h> header file, and it defines `DIR'.
   */
#undef HAVE_SYS_NDIR_H

/* Define to 1 if you have the <sys/resource.h> header file. */
#undef HAVE_SYS_RESOURCE_H

/* Define to 1 if you have the <sys/stat.h> header file. */
#undef HAVE_SYS_STAT_H

/* Define to 1 if you have the <sys/times.h> header file. */
#undef HAVE_SYS_TIMES_H

/* Define to 1 if you have the <sys/types.h> header file. */
#undef HAVE_SYS_TYPES_H

/* Define to 1 if you have the `telldir' function. */
#undef HAVE_TELLDIR

/* define if the compiler supports basic templates */
#undef HAVE_TEMPLATES

/* Define to 1 if you have the <tiffconf.h> header file. */
#undef HAVE_TIFFCONF_H

/* Define to 1 if you have the `TIFFIsCODECConfigured' function. */
#undef HAVE_TIFFISCODECCONFIGURED

/* Define to 1 if you have the `TIFFMergeFieldInfo' function. */
#undef HAVE_TIFFMERGEFIELDINFO

/* Define to 1 if you have the `TIFFSetErrorHandlerExt' function. */
#undef HAVE_TIFFSETERRORHANDLEREXT

/* Define to 1 if you have the `TIFFSetTagExtender' function. */
#undef HAVE_TIFFSETTAGEXTENDER

/* Define to 1 if you have the `TIFFSetWarningHandlerExt' function. */
#undef HAVE_TIFFSETWARNINGHANDLEREXT

/* Define to 1 if you have the `TIFFSwabArrayOfTriples' function. */
#undef HAVE_TIFFSWABARRAYOFTRIPLES

/* Define to 1 if you have the `times' function. */
#undef HAVE_TIMES

/* Define to 1 if you have the `ulltostr' function. */
#undef HAVE_ULLTOSTR

/* Define to 1 if you have the <unistd.h> header file. */
#undef HAVE_UNISTD_H

/* Define to 1 if you have the `vsnprintf' function. */
#undef HAVE_VSNPRINTF

/* Define to 1 if you have the `vsprintf' function. */
#undef HAVE_VSPRINTF

/* Define to 1 if you have the <wincrypt.h> header file. */
#undef HAVE_WINCRYPT_H

/* Define to 1 if you have the `_exit' function. */
#undef HAVE__EXIT

/* Define to 1 if you have the `_NSGetExecutablePath' function. */
#undef HAVE__NSGETEXECUTABLEPATH

/* Define to 1 if you have the `_pclose' function. */
#undef HAVE__PCLOSE

/* Define to 1 if you have the `_popen' function. */
#undef HAVE__POPEN

/* Define if you have the bzip2 library */
#define HasBZLIB

/* Define if you have Display Postscript */
#undef HasDPS

/* Define if you have FlashPIX library */
#undef HasFPX

/* Define if you have JBIG library */
/* #undef HasJBIG */

/* Define if you have JPEG version 2 "Jasper" library */
#undef HasJP2

/* Define if you have JPEG library */
#define HasJPEG

/* Define if you have LCMS (v2.0 or later) library */
#undef HasLCMS

/* Define if using libltdl to support dynamically loadable modules */
#undef HasLTDL

/* Define if you have lzma compression library */
#undef HasLZMA

/* Define if you have Solaris mtmalloc library */
#undef HasMTMALLOC

/* Define if you have PNG library */
#define HasPNG

/* X11 server supports shape extension */
#undef HasShape

/* X11 server supports shared memory extension */
#undef HasSharedMemory

/* Define if you have Google perftools tcmalloc (minimal) library */
#undef HasTCMALLOC

/* Define if you have TIFF library */
#define HasTIFF

/* Define if you have TRIO vsnprintf replacement library */
#undef HasTRIO

/* Define if you have FreeType (TrueType font) library */
#define HasTTF

/* Define if you have umem memory allocation library */
#undef HasUMEM

/* Define if you have WEBP library */
#undef HasWEBP

/* Define to use the Windows GDI32 library */
#define HasWINGDI32

/* Define if you have wmflite library */
#undef HasWMFlite

/* Define if you have X11 library */
#undef HasX11

/* Define if you have XML library */
#undef HasXML

/* Define if you have zlib compression library */
#define HasZLIB

/* Define if you have zstd compression library */
#undef HasZSTD

/* Define to the sub-directory where libtool stores uninstalled libraries. */
#undef LT_OBJDIR

/* Define to prepend to default font search path. */
#undef MAGICK_FONT_PATH

/* Command which returns total physical memory in bytes */
#undef MAGICK_PHYSICAL_MEMORY_COMMAND

/* Target Host CPU */
#undef MAGICK_TARGET_CPU

/* Target Host OS */
#undef MAGICK_TARGET_OS

/* Target Host Vendor */
#undef MAGICK_TARGET_VENDOR

/* define if the compiler lacks ios::binary */
#undef MISSING_STD_IOS_BINARY

/* Directory where executables are installed. */
#undef MagickBinPath

/* Location of coder modules */
#undef MagickCoderModulesPath

/* Subdirectory of lib where coder modules are installed */
#undef MagickCoderModulesSubdir

/* Location of filter modules */
#undef MagickFilterModulesPath

/* Subdirectory of lib where filter modules are installed */
#undef MagickFilterModulesSubdir

/* Directory where architecture-dependent configuration files live. */
#undef MagickLibConfigPath

/* Subdirectory of lib where architecture-dependent configuration files live.
   */
#undef MagickLibConfigSubDir

/* Directory where architecture-dependent files live. */
#undef MagickLibPath

/* Subdirectory of lib where GraphicsMagick architecture dependent files are
   installed */
#undef MagickLibSubdir

/* Directory where architecture-independent configuration files live. */
#undef MagickShareConfigPath

/* Subdirectory of lib where architecture-independent configuration files
   live. */
#undef MagickShareConfigSubDir

/* Directory where architecture-independent files live. */
#undef MagickSharePath

/* Define to the address where bug reports for this package should be sent. */
#undef PACKAGE_BUGREPORT

/* Define to the full name of this package. */
#undef PACKAGE_NAME

/* Define to the full name and version of this package. */
#undef PACKAGE_STRING

/* Define to the one symbol short name of this package. */
#undef PACKAGE_TARNAME

/* Define to the home page for this package. */
#undef PACKAGE_URL

/* Define to the version of this package. */
#undef PACKAGE_VERSION

/* Prefix Magick library symbols with a common string. */
#undef PREFIX_MAGICK_SYMBOLS

/* Define to necessary symbol if this constant uses a non-standard name on
   your system. */
#undef PTHREAD_CREATE_JOINABLE

/* Number of bits in a pixel Quantum (8/16/32) */
#define QuantumDepth 16

/* Define as the return type of signal handlers (`int' or `void'). */
#undef RETSIGTYPE

/* Setjmp/longjmp are thread safe */
#undef SETJMP_IS_THREAD_SAFE

/* The size of `off_t', as computed by sizeof. */
#undef SIZEOF_OFF_T

/* The size of `signed int', as computed by sizeof. */
#undef SIZEOF_SIGNED_INT

/* The size of `signed long', as computed by sizeof. */
#undef SIZEOF_SIGNED_LONG

/* The size of `signed long long', as computed by sizeof. */
#undef SIZEOF_SIGNED_LONG_LONG

/* The size of `signed short', as computed by sizeof. */
#undef SIZEOF_SIGNED_SHORT

/* The size of `size_t', as computed by sizeof. */
#undef SIZEOF_SIZE_T

/* The size of `unsigned int', as computed by sizeof. */
#undef SIZEOF_UNSIGNED_INT

/* The size of `unsigned int*', as computed by sizeof. */
#undef SIZEOF_UNSIGNED_INTP

/* The size of `unsigned long', as computed by sizeof. */
#undef SIZEOF_UNSIGNED_LONG

/* The size of `unsigned long long', as computed by sizeof. */
#undef SIZEOF_UNSIGNED_LONG_LONG

/* The size of `unsigned short', as computed by sizeof. */
#undef SIZEOF_UNSIGNED_SHORT

/* Define to 1 if you have the ANSI C header files. */
#undef STDC_HEADERS

/* Enable extensions on AIX 3, Interix.  */
#ifndef _ALL_SOURCE
# undef _ALL_SOURCE
#endif
/* Enable GNU extensions on systems that have them.  */
#ifndef _GNU_SOURCE
# undef _GNU_SOURCE
#endif
/* Enable threading extensions on Solaris.  */
#ifndef _POSIX_PTHREAD_SEMANTICS
# undef _POSIX_PTHREAD_SEMANTICS
#endif
/* Enable extensions on HP NonStop.  */
#ifndef _TANDEM_SOURCE
# undef _TANDEM_SOURCE
#endif
/* Enable general extensions on Solaris.  */
#ifndef __EXTENSIONS__
# undef __EXTENSIONS__
#endif


/* GraphicsMagick is formally installed under prefix */
#undef UseInstalledMagick

/* Define WORDS_BIGENDIAN to 1 if your processor stores words with the most
   significant byte first (like Motorola and SPARC, unlike Intel). */
#if defined AC_APPLE_UNIVERSAL_BUILD
# if defined __BIG_ENDIAN__
#  define WORDS_BIGENDIAN 1
# endif
#else
# ifndef WORDS_BIGENDIAN
#  undef WORDS_BIGENDIAN
# endif
#endif

/* Location of X11 configure files */
#undef X11ConfigurePath

/* Define to 1 if the X Window System is missing or not being used. */
#undef X_DISPLAY_MISSING

/* Enable large inode numbers on Mac OS X 10.5.  */
#ifndef _DARWIN_USE_64_BIT_INODE
# define _DARWIN_USE_64_BIT_INODE 1
#endif

/* Number of bits in a file offset, on hosts where this is settable. */
#undef _FILE_OFFSET_BITS

/* Define to 1 to make fseeko visible on some hosts (e.g. glibc 2.2). */
#undef _LARGEFILE_SOURCE

/* Define for large files, on AIX-style hosts. */
#undef _LARGE_FILES

/* Define to 1 if on MINIX. */
#undef _MINIX

/* Define to 2 if the system does not provide POSIX.1 features except with
   this defined. */
#undef _POSIX_1_SOURCE

/* Define to 1 if you need to in order for `stat' and other things to work. */
#undef _POSIX_SOURCE

/* Define to 1 if type `char' is unsigned and you are not using gcc.  */
#ifndef __CHAR_UNSIGNED__
# undef __CHAR_UNSIGNED__
#endif

/* Define to empty if `const' does not conform to ANSI C. */
#undef const

/* Define to `__inline__' or `__inline' if that's what the C compiler
   calls it, or to nothing if 'inline' is not supported under any name.  */
#ifndef __cplusplus
#undef inline
#endif

/* Define to `int' if <sys/types.h> does not define. */
#undef mode_t

/* Define to `long int' if <sys/types.h> does not define. */
#undef off_t

/* Define to `int' if <sys/types.h> does not define. */
#undef pid_t

/* Define to the equivalent of the C99 'restrict' keyword, or to
   nothing if this is not supported.  Do not define if restrict is
   supported directly.  */
#define restrict
/* Work around a bug in Sun C++: it does not support _Restrict or
   __restrict__, even though the corresponding Sun C compiler ends up with
   "#define restrict _Restrict" or "#define restrict __restrict__" in the
   previous line.  Perhaps some future version of Sun C++ will work with
   restrict; if so, hopefully it defines __RESTRICT like Sun C does.  */
#if defined __SUNPRO_CC && !defined __RESTRICT
# define _Restrict
# define __restrict__
#endif

/* Define to `unsigned int' if <sys/types.h> does not define. */
/* #undef size_t */

/* Define to `int' if <sys/types.h> does not define. */
#undef ssize_t
