



gm -help
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_PREFIX%\\bin\\GraphicsMagick.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_PREFIX%\\bin\\GraphicsMagick++.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_PREFIX%\\bin\\GraphicsMagickWand.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
